@@ -24,7 +24,9 @@ def test_graph():
         (9, 10, {'type': 'works_at'}),
         (11, 3, {'type': 'lives_in'}),
         (12, 5, {'type': 'lives_in'}),
-        (12, 13, {'type': 'works_at'})
+        (12, 13, {'type': 'works_at'}),
+        (13, 5, {'type': 'located_in'}),
+        (13, 14, {'type': 'works_at'})
     ])
     g.node[1] = {'type': 'Person', 'name': 'davebshow'}
     g.node[2] = {'type': 'Institution', 'name': 'western'}
@@ -39,6 +41,7 @@ def test_graph():
     g.node[11] = {'type': 'Person', 'name': 'curly'}
     g.node[12] = {'type': 'Person', 'name': 'adam'}
     g.node[13] = {'type': 'Institution', 'name': 'canland'}
+    g.node[14] = {'type': 'Person', 'name': 'bro'}
     return g
 
 
